package com.ruoyi.web.controller.app;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.equipment.domain.Equipment;
import com.ruoyi.ss.equipment.domain.EquipmentQuery;
import com.ruoyi.ss.equipment.domain.EquipmentVO;
import com.ruoyi.ss.equipment.service.IEquipmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author qzz
 * 2024/7/22
 */
@RestController
@RequestMapping("/app/equipment")
public class AppEquipmentController extends BaseController {

    @Autowired
    private IEquipmentService equipmentService;

    /**
     * 查询设施列表
     */
    @GetMapping("/list")
    public TableDataInfo list(EquipmentQuery query)
    {
        startPage();
        startOrderBy();
        List<EquipmentVO> list = equipmentService.selectEquipmentList(query);
        return getDataTable(list);
    }

    /**
     * 获取设施详细信息
     */
    @GetMapping(value = "/{equipmentId}")
    public AjaxResult getInfo(@PathVariable("equipmentId") Long equipmentId)
    {
        return success(equipmentService.selectEquipmentByEquipmentId(equipmentId));
    }

    /**
     * 新增设施
     */
    @Log(title = "设施", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Equipment equipment)
    {
        logger.info("【新增设施】，请求参数=【{}】", JSON.toJSON(equipment));
        return toAjax(equipmentService.insertEquipment(equipment));
    }

    /**
     * 修改设施
     */
    @Log(title = "设施", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Equipment equipment)
    {
        logger.info("【修改设施】，请求参数=【{}】", JSON.toJSON(equipment));
        return toAjax(equipmentService.updateEquipment(equipment));
    }

    /**
     * 删除设施
     */
    @Log(title = "设施", businessType = BusinessType.DELETE)
    @DeleteMapping("/{equipmentIds}")
    public AjaxResult remove(@PathVariable Long[] equipmentIds)
    {
        logger.info("删除设施：【{}】", JSON.toJSONString(equipmentIds));
        return toAjax(equipmentService.deleteEquipmentByEquipmentIds(equipmentIds));
    }
}
