package com.ruoyi.web.controller.app;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.ss.feeRule.domain.FeeRule;
import com.ruoyi.ss.feeRule.domain.FeeRuleDTO;
import com.ruoyi.ss.feeRule.domain.FeeRuleQuery;
import com.ruoyi.ss.feeRule.domain.FeeRuleVO;
import com.ruoyi.ss.feeRule.service.IFeeRuleConverter;
import com.ruoyi.ss.feeRule.service.IFeeRuleService;
import com.ruoyi.ss.room.domain.RoomVO;
import com.ruoyi.ss.room.service.IRoomService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 套餐Controller
 * @author qzz
 * 2024/3/5
 */
@Api(tags = "套餐")
@RestController
@RequestMapping("/app/rule")
public class AppRuleController extends BaseController {

    @Autowired
    private IFeeRuleService feeRuleService;

    @Resource
    private IFeeRuleConverter feeRuleConverter;

    @Autowired
    private IRoomService roomService;


    /**
     * 套餐列表
     */
    @GetMapping("/list")
    public AjaxResult list(FeeRuleQuery feeRuleQuery)
    {
        logger.info("套餐列表：【feeRuleQuery={}】", JSON.toJSONString(feeRuleQuery));
        List<FeeRuleVO> list = feeRuleService.selectEFeeRuleList(feeRuleQuery);
        return success(list);
    }

    /**
     * 根据房间id获取套餐
     */
    @GetMapping("/getListByRoomId")
    public AjaxResult ruleList(Long roomId)
    {
        ServiceUtil.assertion(roomId == null, "房间id不能为空");
        logger.info("根据房间id获取套餐：【roomId={}】", roomId);
        RoomVO roomVO = roomService.selectERoomByRoomId(roomId);
        ServiceUtil.assertion(roomVO == null, "房间不存在");
        List<FeeRuleVO> list = feeRuleService.selectEFeeRuleListByRuleIds(roomVO.getRuleIds());
        return success(list);
    }

    /**
     * 新增收费模板
     */
    @Log(title = "新增收费模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated({ValidGroup.Create.class}) FeeRuleDTO eFeeRule)
    {
        logger.info("新增收费模板：【{}】", JSON.toJSONString(eFeeRule));
        FeeRule rule = feeRuleConverter.toOrderBO(eFeeRule);
        return toAjax(feeRuleService.insertEFeeRule(rule));
    }

    /**
     * 修改收费模板
     */
    @Log(title = "修改收费模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult editRule(@RequestBody @Validated({ValidGroup.Update.class}) FeeRuleDTO rlFeeRule)
    {
        logger.info("修改收费模板：【{}】", JSON.toJSONString(rlFeeRule));
        FeeRule rule = feeRuleConverter.toOrderBO(rlFeeRule);
        return toAjax(feeRuleService.updateEFeeRule(rule));
    }


}
