package com.ruoyi.ss.equipment.mapper;

import java.util.List;

import com.ruoyi.ss.equipment.domain.Equipment;
import com.ruoyi.ss.equipment.domain.EquipmentQuery;
import com.ruoyi.ss.equipment.domain.EquipmentVO;
import org.apache.ibatis.annotations.Param;

/**
 * 设施Mapper接口
 *
 * @author qzz
 * @date 2024-12-21
 */
public interface EquipmentMapper
{
    /**
     * 查询设施
     *
     * @param equipmentId 设施主键
     * @return 设施
     */
    public EquipmentVO selectEquipmentByEquipmentId(Long equipmentId);

    /**
     * 查询设施列表
     *
     * @param query 设施
     * @return 设施集合
     */
    public List<EquipmentVO> selectEquipmentList(@Param("query") EquipmentQuery query);

    /**
     * 新增设施
     *
     * @param equipment 设施
     * @return 结果
     */
    public int insertEquipment(Equipment equipment);

    /**
     * 修改设施
     *
     * @param equipment 设施
     * @return 结果
     */
    public int updateEquipment(@Param("data") Equipment equipment);

    /**
     * 删除设施
     *
     * @param equipmentId 设施主键
     * @return 结果
     */
    public int deleteEquipmentByEquipmentId(Long equipmentId);

    /**
     * 批量删除设施
     *
     * @param equipmentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquipmentByEquipmentIds(Long[] equipmentIds);


    /**
     * 设备投放的房间id
     * @param deviceId 设备id
     * @return String
     */
    List<Long> selectRoomIdByDeviceId(Long deviceId);

    /**
     * 根据房间id查询设施列表
     *
     * @param roomId 房间id
     * @return 设施集合
     */
    List<EquipmentVO> selectEquipmentListByRoomId(Long roomId);
}
