package com.ruoyi.ss.equipment.service;

import com.ruoyi.ss.equipment.domain.Equipment;
import com.ruoyi.ss.equipment.domain.EquipmentQuery;
import com.ruoyi.ss.equipment.domain.EquipmentVO;

import java.util.List;

/**
 * 设施Service接口
 *
 * @author qzz
 * @date 2024-12-21
 */
public interface IEquipmentService
{
    /**
     * 查询设施
     *
     * @param equipmentId 设施主键
     * @return 设施
     */
    public EquipmentVO selectEquipmentByEquipmentId(Long equipmentId);

    /**
     * 查询设施列表
     *
     * @param equipment 设施
     * @return 设施集合
     */
    public List<EquipmentVO> selectEquipmentList(EquipmentQuery equipment);

    /**
     * 根据房间id查询设施列表
     *
     * @param roomId 房间id
     * @return 设施集合
     */
    public List<EquipmentVO> selectEquipmentListByRoomId(Long roomId);

    /**
     * 新增设施
     *
     * @param equipment 设施
     * @return 结果
     */
    public int insertEquipment(Equipment equipment);

    /**
     * 修改设施
     *
     * @param equipment 设施
     * @return 结果
     */
    public int updateEquipment(Equipment equipment);

    /**
     * 批量删除设施
     *
     * @param equipmentIds 需要删除的设施主键集合
     * @return 结果
     */
    public int deleteEquipmentByEquipmentIds(Long[] equipmentIds);

    /**
     * 删除设施信息
     *
     * @param equipmentId 设施主键
     * @return 结果
     */
    public int deleteEquipmentByEquipmentId(Long equipmentId);

    /**
     * 设备投放的房间id
     * @param deviceId 设备id
     * @return String
     */
    List<Long> selectRoomIdByDeviceId(Long deviceId);
}
