package com.ruoyi.ss.equipment.service.impl;

import java.util.Collections;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.ss.equipment.domain.Equipment;
import com.ruoyi.ss.equipment.domain.EquipmentQuery;
import com.ruoyi.ss.equipment.domain.EquipmentVO;
import com.ruoyi.ss.equipment.mapper.EquipmentMapper;
import com.ruoyi.ss.equipment.service.IEquipmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 设施Service业务层处理
 *
 * @author qzz
 * @date 2024-12-21
 */
@Service
public class EquipmentServiceImpl implements IEquipmentService
{
    @Autowired
    private EquipmentMapper equipmentMapper;

    /**
     * 查询设施
     *
     * @param equipmentId 设施主键
     * @return 设施
     */
    @Override
    public EquipmentVO selectEquipmentByEquipmentId(Long equipmentId)
    {
        return equipmentMapper.selectEquipmentByEquipmentId(equipmentId);
    }

    /**
     * 查询设施列表
     *
     * @param equipment 设施
     * @return 设施
     */
    @Override
    public List<EquipmentVO> selectEquipmentList(EquipmentQuery equipment)
    {
        return equipmentMapper.selectEquipmentList(equipment);
    }


    /**
     * 根据房间id查询设施列表
     *
     * @param roomId 房间id
     * @return 设施集合
     */
    @Override
    public List<EquipmentVO> selectEquipmentListByRoomId(Long roomId) {
        return equipmentMapper.selectEquipmentListByRoomId(roomId);
    }

    /**
     * 新增设施
     *
     * @param equipment 设施
     * @return 结果
     */
    @Override
    public int insertEquipment(Equipment equipment)
    {
        equipment.setCreateTime(DateUtils.getNowDate());
        return equipmentMapper.insertEquipment(equipment);
    }

    /**
     * 修改设施
     *
     * @param equipment 设施
     * @return 结果
     */
    @Override
    public int updateEquipment(Equipment equipment)
    {
        return equipmentMapper.updateEquipment(equipment);
    }

    /**
     * 批量删除设施
     *
     * @param equipmentIds 需要删除的设施主键
     * @return 结果
     */
    @Override
    public int deleteEquipmentByEquipmentIds(Long[] equipmentIds)
    {
        return equipmentMapper.deleteEquipmentByEquipmentIds(equipmentIds);
    }

    /**
     * 删除设施信息
     *
     * @param equipmentId 设施主键
     * @return 结果
     */
    @Override
    public int deleteEquipmentByEquipmentId(Long equipmentId)
    {
        return equipmentMapper.deleteEquipmentByEquipmentId(equipmentId);
    }

    /**
     * 设备投放的房间id
     * @param deviceId 设备id
     * @return String
     */
    @Override
    public List<Long> selectRoomIdByDeviceId(Long deviceId) {
        return equipmentMapper.selectRoomIdByDeviceId(deviceId);
    }
}
