package com.ruoyi.ss.room.service;

import java.util.List;

import com.ruoyi.ss.room.domain.*;

/**
 * 房间Service接口 店长
 *
 * @author qzz
 * @date 2024-11-20
 */
public interface IRoomService
{
    /**
     * 查询房间
     *
     * @param roomId 房间主键
     * @return 房间
     */
    public RoomVO selectERoomByRoomId(Long roomId);
//
//    /**
//     * 查询房间(不带拼接)
//     *
//     * @param roomId 房间主键
//     * @return 房间
//     */
//    public RoomVO selectSimpleRoomByRoomId(Long roomId);

    /**
     * 查询房间列表
     *
     * @param eRoom 房间
     * @return 房间集合
     */
    public List<RoomVO> selectERoomList(RoomQuery eRoom);

    /**
     * 根据店铺id查询房间列表
     *
     * @param storeId 店铺id
     * @return 房间集合
     */
    public List<RoomVO> selectERoomListByStoreId(Long storeId);

    /**
     * 新增房间
     *
     * @param eRoom 房间
     * @return 结果
     */
    public int insertERoom(Room eRoom);

    /**
     * 修改房间
     *
     * @param eRoom 房间
     * @return 结果
     */
    public int updateERoom(Room eRoom);

    /**
     * 批量删除房间
     *
     * @param roomIds 需要删除的房间主键集合
     * @return 结果
     */
    public int deleteERoomByRoomIds(Long[] roomIds);

    /**
     * 删除房间信息
     *
     * @param roomId 房间主键
     * @return 结果
     */
    public int deleteERoomByRoomId(Long roomId);

    /**
     * 开门
     * @param eRoomVO 房间对象
     * @return String
     */
    boolean openGate(RoomVO eRoomVO);

    /**
     * 根据店铺查房间
     * @param storeId 店铺id
     * @return String
     */
    List<RoomVO> getRoomListByStoreId(Long storeId);

    /**
     * 下架设备
     * @param deviceId 设备id
     * @return String
     */
    public int offlineDevice(Long deviceId);

    /**
     * 绑定房间门
     * @param eRoom 房间对象
     * @return String
     */
    int bandDoor(RoomDTO eRoom);

    /**
     * 新建大厅设备（房间级别） 转换
     */
    int addLobbyDevice(Room room);

    /**
     * 应用套餐
     */
    int bandRule(BandRuleDTO dto);

    /**
     * 解除套餐
     */
    int unBandRule(Long ruleId,Long roomId);
}
